@@ -18,12 +18,8 @@ static Pixmap exp_bkp = 0;
 static void hide_exposed_card(void)
 {   if (rem_y < 0)
 	return;
-#if 0
-    draw_pileupdate(getpile(graphic.zoomed_card), 0);
-#else
     XCopyArea(dpy, exp_bkp, table, whitegc, 0, 0, CARD_WIDTH, CARD_HEIGHT,
 	      graphic.pile[getpile(graphic.zoomed_card)].x, rem_y);
-#endif
     rem_y = -1;
     graphic.zoomed_card = -1;
 }
