@@ -144,40 +144,41 @@ static void read_cardconfig(const char *filename) {
     cc.Ry = 6;
     cc.Sx = 3;
     cc.Sy = cc.y0 + SUITSIZE1 - SUITSIZE3;
-    /* possibility to override the defaults */
-    if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
-	cc.numbacks = tmp[0], cc.numjokers = tmp[1];
-    if (fscanf(fp, "%d", tmp) == 1)
-	cc.flags = tmp[0];
-    if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
-	cc.Ox = tmp[0],	cc.Oy = tmp[1];
-    if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
-	cc.Mx = tmp[0],	cc.My = tmp[1];
-    if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
-	cc.Rx = tmp[0],	cc.Ry = tmp[1];
-    if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
-	cc.Sx = tmp[0],	cc.Sy = tmp[1];
-    if (fscanf(fp, "%d %d", tmp, tmp+1) == 2) {	/* xdelta and ydelta */
-	cc.x0 += tmp[0], cc.x2 -= tmp[0],
-	cc.y0 += 3 * tmp[1];
-	cc.y1 += 2 * tmp[1];
-	cc.y2 += 1 * tmp[1];
-	cc.y4 -= 1 * tmp[1];
-	cc.y5 -= 2 * tmp[1];
-	cc.y6 -= 3 * tmp[1];
-	tmp[1] = tmp[1] * 3 / 2;
-	cc.y7 += tmp[1];
-	cc.y8 -= tmp[1];
-    }
-    if (fscanf(fp, "%d %d %d", tmp, tmp+1, tmp+2) == 3)
-	cc.x0 = tmp[0],	cc.x1 = tmp[1], cc.x2 = tmp[2];
-    if (fscanf(fp, "%d %d %d %d %d %d %d %d %d", tmp, tmp+1, tmp+2, tmp+3,
-	       tmp+4, tmp+5, tmp+6, tmp+7, tmp+8) == 9)
-	cc.y0 = tmp[0],	cc.y1 = tmp[1], cc.y2 = tmp[2],
-	cc.y3 = tmp[3],	cc.y4 = tmp[4], cc.y5 = tmp[5],
-	cc.y6 = tmp[6],	cc.y7 = tmp[7], cc.y8 = tmp[8];
-    if (fp)
+    if (fp) {	/* Cards.Conf does exist */
+	/* possibility to override the defaults */
+	if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
+	    cc.numbacks = tmp[0], cc.numjokers = tmp[1];
+	if (fscanf(fp, "%d", tmp) == 1)
+	    cc.flags = tmp[0];
+	if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
+	    cc.Ox = tmp[0],	cc.Oy = tmp[1];
+	if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
+	    cc.Mx = tmp[0],	cc.My = tmp[1];
+	if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
+	    cc.Rx = tmp[0],	cc.Ry = tmp[1];
+	if (fscanf(fp, "%d %d", tmp, tmp+1) == 2)
+	    cc.Sx = tmp[0],	cc.Sy = tmp[1];
+	if (fscanf(fp, "%d %d", tmp, tmp+1) == 2) {	/* xdelta and ydelta */
+	    cc.x0 += tmp[0], cc.x2 -= tmp[0],
+	    cc.y0 += 3 * tmp[1];
+	    cc.y1 += 2 * tmp[1];
+	    cc.y2 += 1 * tmp[1];
+	    cc.y4 -= 1 * tmp[1];
+	    cc.y5 -= 2 * tmp[1];
+	    cc.y6 -= 3 * tmp[1];
+	    tmp[1] = tmp[1] * 3 / 2;
+	    cc.y7 += tmp[1];
+	    cc.y8 -= tmp[1];
+	}
+	if (fscanf(fp, "%d %d %d", tmp, tmp+1, tmp+2) == 3)
+	    cc.x0 = tmp[0],	cc.x1 = tmp[1], cc.x2 = tmp[2];
+	if (fscanf(fp, "%d %d %d %d %d %d %d %d %d", tmp, tmp+1, tmp+2, tmp+3,
+		   tmp+4, tmp+5, tmp+6, tmp+7, tmp+8) == 9)
+	    cc.y0 = tmp[0],	cc.y1 = tmp[1], cc.y2 = tmp[2],
+	    cc.y3 = tmp[3],	cc.y4 = tmp[4], cc.y5 = tmp[5],
+	    cc.y6 = tmp[6],	cc.y7 = tmp[7], cc.y8 = tmp[8];
 	fclose(fp);
+    }
     if (cc.flags & PRINT)
 	printf("y = %d %d %d  %d %d %d  %d %d %d, x = %d %d %d\n",
 	   cc.y0, cc.y1, cc.y2,
@@ -382,8 +383,24 @@ static struct picture {
 static int read_xpmfile(const char *name, struct picture *p) {
     XpmAttributes attribs;
     attribs.valuemask = 0;
-    if (XpmReadFileToPixmap(dpy, table, xpmname(name, "xpm"), &p->map, &p->clip, &attribs) != XpmSuccess)
+    switch (XpmReadFileToPixmap(dpy, table, xpmname(name, "xpm"), &p->map, &p->clip, &attribs)) {
+    case XpmSuccess:
+	break;	/* yeah! */
+    case XpmColorError:
+    case XpmColorFailed:
+	fprintf(stderr, "xpm: Not enough colors.\n");
 	return p->flag = 0;
+    case XpmFileInvalid:
+	fprintf(stderr, "xpm: Invalid file.\n");
+	return p->flag = 0;
+    case XpmNoMemory:
+	fprintf(stderr, "xpm: Out of memory.\n");
+	return p->flag = 0;
+    case XpmOpenFailed:
+    default:
+	/* maybe not serious */
+	return p->flag = 0;
+    }
     p->w = attribs.width;
     p->h = attribs.height;
     return p->flag = 1;
