@@ -19,6 +19,7 @@
 #define MICHAELS_MAGIC		0x3c0
 #define ROYAL_MAGIC		0x3e0
 #define BAKERS_MAGIC		0x400
+#define CANFIELD_MAGIC		0x420
 
 #define MCDX 14
 #define MCDY 4
@@ -29,7 +30,13 @@
 
 void new_rules_notify(void) {
     XSize_t w, h;
+#ifdef useXview
+    xv_set(mainwindow,
+	   FRAME_LABEL, (rules.longname? rules.longname: rules.shortname),
+	   0);
+#else
     XStoreName(dpy, mainwindow, rules.longname ? rules.longname : rules.shortname);
+#endif
     refresh_screen();		/* sometimes needed (at least if area is smaller) */
     
     /* compute minimum size */
@@ -211,6 +218,11 @@ void generic_minwindow(XSize_t *x, XSize_t *y) {
 	*x = graphic.xgap + min1 * (CARD_WIDTH + graphic.xgap);
 	*y = calc_yoff(*x) + (CARD_HEIGHT + graphic.ygap) * 4;
 	return;
+    case 8:	/* Canfield */
+	/* No deck, 4 stacks, a dozen slots */
+	*x = graphic.xgap + 5 * (CARD_WIDTH + graphic.xgap);
+	*y = calc_yoff(*x) + (CARD_HEIGHT + graphic.ygap) * 4;
+	return;
     }
 }
 
@@ -393,13 +405,12 @@ static int Delight_Layout(int xnum, int ynum, int h) {
     p->xtotal = CARD_WIDTH;
     p->ymaxheight = CARD_HEIGHT;
 
-#if 1	/* want dest. for hint arrows */
+    /* want dest. for hint arrows */
     p = graphic.pile+FIRST_STACK;
     p->x = x;
     p->y = YOFF + CARD_HEIGHT + graphic.ygap;
     p->xtotal = CARD_WIDTH;
     p->ymaxheight = CARD_HEIGHT;
-#endif
 
     p = graphic.pile+FIRST_SLOT;
     for (i = 0; i < rules.numslots; ++i) {
@@ -586,6 +597,38 @@ static int Bakers_Layout(int xnum, int ynum, int h) {
     return BAKERS_MAGIC;
 }
 
+static int Canfield_Layout(int xnum, int ynum, int h) {
+    int i;
+    struct pile *p;
+
+    for (i = FIRST_SLOT; i <= LAST_SLOT; ++i) {
+	p = graphic.pile+i;
+	p->x = graphic.xgap + (i - FIRST_SLOT+1) * (CARD_WIDTH + graphic.xgap);
+	p->y = YOFF + (CARD_HEIGHT + graphic.ygap);
+	p->ymaxheight = 3 * CARD_HEIGHT + graphic.ygap;
+    }
+    for (i = FIRST_STACK; i <= LAST_STACK; ++i) {
+	p = graphic.pile+i;
+	p->x = graphic.xgap + (i+1) * (CARD_WIDTH + graphic.xgap);
+	p->y = YOFF;
+    }
+    p = graphic.pile + LAST_SLOT + 1;
+    /* the stock */
+    p->x = graphic.xgap;
+    p->y = YOFF + (CARD_HEIGHT + graphic.ygap)/2;
+    
+    ++p;
+    /* the talon */
+    p->x = graphic.xgap;
+    p->y = p[-1].y + (CARD_HEIGHT + graphic.ygap);
+
+    ++p;
+    /* the hand */
+    p->x = graphic.xgap;
+    p->y = p[-1].y + (CARD_HEIGHT + graphic.ygap);
+    return CANFIELD_MAGIC;
+}
+
 void init_layout(void) {
     int w, h;
     static int layout_type = -1, yoff = -1;
@@ -595,7 +638,7 @@ void init_layout(void) {
     int xnum, ynum;	/* number of cards in either direction */
 
     /* get the size of the actual window */
-#ifdef useAthenaWidgets
+#ifdef useXaw
     w = graphic.w_width;
     h = graphic.w_height;
 #else
@@ -667,6 +710,9 @@ void init_layout(void) {
     case 7:
 	new_layout_type = Bakers_Layout(xnum, ynum, h);
 	break;
+    case 8:
+	new_layout_type = Canfield_Layout(xnum, ynum, h);
+	break;
     default:
 	new_layout_type = 0xffff;	/* keep compiler happy */
 	assert(0);
