@@ -10,19 +10,23 @@
 /*****************************************************************************/
 #include "X-pat.h"
 
+#ifndef AUDIO_DEVICE
+#define AUDIO_DEVICE "/dev/audio"
+#endif
+
 void play_sound(const char *filename) {
     static int audio = 1;
     if (audio && checksound()) {
 	char fullname[200];
 	FILE *fp, *fsnd;
 	int c;
-	if (!(fsnd = fopen("/dev/audio", "w"))) {
+	if (!(fsnd = fopen(AUDIO_DEVICE, "wb"))) {
 	    audio = 0;
 	    return;		/* cannot open /dev/audio */
 	}
 	XSync(dpy, 0);	/* text first! */
 	sprintf(fullname, "%s/audio/%s.au", LIBDIR, filename);
-	if (!(fp = fopen(fullname, "r"))) {
+	if (!(fp = fopen(fullname, "rb"))) {
 	    fclose(fsnd);
 	    return;
 	}
