@@ -15,6 +15,7 @@
 #include "Tableau.h"
 #include "version.h"
 
+Window table, mainwindow;
 Widget toplevel;
 
 static void perform_command(Widget widget, XtPointer client_data, XtPointer call_data) {
@@ -123,6 +124,7 @@ static String fallback_resources[] = {
     "*Tableau.arrowColor:		Gold",
     "*Tableau.markColor:		Black",
     "*Tableau.rules:		        Gypsy",
+    "*Tableau.rng:		        1",
     "*Viewport.allowHoriz:		True",
     "*Viewport.allowVert:		True",
     "*Viewport.useBottom:		True",
@@ -163,6 +165,7 @@ static XrmOptionDescRec options[] = {
     { "-flips",        	"*Tableau.flips",	XrmoptionSepArg, NULL },
     { "-turn",		"*Tableau.turn",	XrmoptionSepArg, NULL },
     { "-rotations",	"*Tableau.rotations",	XrmoptionSepArg, NULL },
+    { "-rng",		"*Tableau.rng",		XrmoptionSepArg, NULL },
 #ifdef GFX1
 #ifdef LOADCARDS
     { "-cards",		"*Tableau.cardset",	XrmoptionSepArg, NULL },
@@ -334,26 +337,10 @@ int main(int argc, char *argv[]) {
     };
 
     /* use the command line arguments concerning the widgets */
-
-    uid_t user_user_id = getuid ();
-    uid_t game_user_id = geteuid ();
-  
-#ifdef _POSIX_SAVED_IDS
-    setuid (user_user_id);
-#else
-    setreuid (geteuid (), getuid ());
-#endif
-
-    toplevel = XtAppInitialize(&app_con, "XPat", options, XtNumber(options), &argc, argv,
-			       fallback_resources, NULL, 0);
-
-
-#ifdef _POSIX_SAVED_IDS
-    setuid (game_user_id);
-#else
-    setreuid (geteuid (), getuid ());
-#endif
-
+    switch_uid(1);	/* switch to real uid for reading .Xauthority */
+    toplevel = XtAppInitialize(&app_con, "XPat", options, XtNumber(options),
+			       &argc, argv, fallback_resources, NULL, 0);
+    switch_uid(0);	/* back to effective uid */
     process_extra_args(argc, argv);
     XtAppAddActions(app_con, moreActions, XtNumber(moreActions));
     graphics_control(Disable);
