@@ -28,6 +28,7 @@ void create_help(Widget);
 void popup_help(Widget, XtPointer, XtPointer);
 void popdown_help(Widget, XtPointer, XtPointer);
 
+Window table, mainwindow;
 Widget toplevel;
 static Widget messagebox, container, desktop, sbh, sbv;
 static void perform_command(Widget widget, XtPointer client_data, XtPointer call_data) {
@@ -237,8 +238,10 @@ int main(int argc, char *argv[]) {
     };
 
     /* use the command line arguments concerning the widgets */
+    switch_uid(1);
     toplevel = XtAppInitialize(&app_con, "XPat", options, XtNumber(options), &argc, argv,
 			       fallback_resources, NULL, 0);
+    switch_uid(0);
     process_extra_args(argc, argv);
     XtAppAddActions(app_con, moreActions, XtNumber(moreActions));
     graphics_control(Disable);
