@@ -19,6 +19,13 @@
 #include "version.h"
 #include "pat.bm"
 
+Window table;
+Frame mainwindow;
+Panel buttonbox;
+Canvas canvas;
+Menu cmenu;
+Event *bp_event;
+
 static int audio = 1;
 static Xv_Notice confirm_dialog;
 static Panel_item sound_button;
@@ -249,7 +256,7 @@ static struct option {
 	++cmdname;
     else
 	cmdname = argv[0];
-    if (strcmp(cmdname, "xpat2") != 0)
+    if (strncmp(cmdname, "xpat", 4))
 	options[0].cmdarg = cmdname;
 
     for (i = 1; i < argc - 1; i++)    /* merge command line options */
